@@ -2,7 +2,7 @@
 # PODNAME: App::Prove::Plugin::TestRail
 
 package App::Prove::Plugin::TestRail;
-$App::Prove::Plugin::TestRail::VERSION = '0.018';
+$App::Prove::Plugin::TestRail::VERSION = '0.019';
 use strict;
 use warnings;
 use utf8;
@@ -44,6 +44,7 @@ sub load {
     $ENV{'TESTRAIL_VERSION'} = $params->{version};
     $ENV{'TESTRAIL_CASEOK'}  = $params->{case_per_ok};
     $ENV{'TESTRAIL_STEPS'}   = $params->{step_results};
+    $ENV{'TESTRAIL_SPAWN'}   = $params->{spawn};
     return $class;
 }
 
@@ -82,7 +83,7 @@ App::Prove::Plugin::TestRail - Upload your TAP results to TestRail in realtime
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -107,11 +108,14 @@ If \$HOME/.testrailrc exists, it will be parsed for any of these values in a new
     version=xx.xx.xx.xx
     case_per_ok=0
     step_results=sr_sys_name
+    spawn=123
 
 Note that passing configurations as filters for runs inside of plans are separated by colons.
 Values passed in via query string will override values in \$HOME/.testrailrc.
 If your system has no concept of user homes, it will look in the current directory for .testrailrc.
 
+See the documentation for the constructor of L<Test::Rail::Parser> as to why you might want to pass the aforementioned options.
+
 =head1 OVERRIDDEN METHODS
 
 =head2 load(parser)
